# Wintersong

Wintersong is the collection of web components, styles, and MkDocs theme used by Winterbloom.

## Contributing

While I don't really expect anyone outside of Winterbloom to use these, by all means, contributions are welcome. File an issue or reach out to us before you write code, so we can make sure it's something that'll be beneficial for all of us. :)

## License

Wintersong is published under the [MIT License](LICENSE).
